@@ -1,6 +1,6 @@
 #!/usr/local/bin/perl -w
 
-require 5;
+require 5.000;
 BEGIN {  unshift @INC, "../lib"; }
 use Parse::CLex;
 print STDERR "Version $Parse::ALex::VERSION\n";
